@@ -1369,7 +1369,8 @@ search_activated (ESearchBar *esb, EABView *v)
 		     NULL);
 
 	if (search_type == E_FILTERBAR_ADVANCED_ID) {
-		// gtk_widget_show(eab_search_dialog_new(v));
+		/* rebuild view immediately */
+		query_changed (esb, v);
 	}
 	else {
 		if ((search_word && strlen (search_word))) {
