@@ -1,34 +1,36 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* Evolution CSV and TAB importer
- *
- * Copyright (C) 2005  Novell, Inc.
+/*
+ * Evolution CSV and TAB importer
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Devashish Sharma <sdevashish@novell.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * Authors: Devashish Sharma <sdevashish@novell.com>
  */
+
 #include <config.h>
 #include <stdio.h>
 #include <ctype.h>
 #include <string.h>
 
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
 
-#include <gtk/gtkvbox.h>
-
 #include <libebook/e-book.h>
 #include <libedataserverui/e-source-selector.h>
 
@@ -267,12 +269,19 @@ add_to_notes(EContact *contact, gint i, char *val) {
 	GString *new_text;
 
 	old_text = e_contact_get_const(contact, E_CONTACT_NOTE);
-	if(importer == OUTLOOK_IMPORTER)
-		field_text = csv_fields_outlook[i].csv_attribute;
-	else if(importer == MOZILLA_IMPORTER)
-		field_text = csv_fields_mozilla[i].csv_attribute;
-	else
-		field_text = csv_fields_evolution[i].csv_attribute;
+	if (importer == OUTLOOK_IMPORTER) {
+		if (i >= 0 && i < G_N_ELEMENTS (csv_fields_outlook))
+			field_text = csv_fields_outlook[i].csv_attribute;
+	} else if (importer == MOZILLA_IMPORTER) {
+		if (i >= 0 && i < G_N_ELEMENTS (csv_fields_mozilla))
+			field_text = csv_fields_mozilla[i].csv_attribute;
+	} else {
+		if (i >= 0 && i < G_N_ELEMENTS (csv_fields_evolution))
+			field_text = csv_fields_evolution[i].csv_attribute;
+	}
+
+	if (!field_text)
+		return;
 
 	new_text = g_string_new(old_text);
 	if(strlen(new_text->str) != 0)
@@ -326,9 +335,9 @@ date_from_string (const char *str)
 }
 
 static gboolean
-parseLine (CSVImporter *gci, EContact *contact, char **buf) {
+parseLine (CSVImporter *gci, EContact *contact, char *buf) {
 
-	char *ptr = *buf;
+	char *ptr = buf, *do_free = NULL;
 	GString *value;
 	gint i = 0;
 	int flags = 0;
@@ -344,44 +353,70 @@ parseLine (CSVImporter *gci, EContact *contact, char **buf) {
 	other_address = g_new0(EContactAddress, 1);
 	bday = g_new0(EContactDate, 1);
 
+	if (!g_utf8_validate (ptr, -1, NULL)) {
+		do_free = g_convert (ptr, -1, "UTF-8", "ISO-8859-1", NULL, NULL, NULL);
+		ptr = do_free;
+	}
+
 	while(*ptr != '\n') {
 		value = g_string_new("");
 		while(*ptr != delimiter) {
 			if(*ptr == '\n')
 				break;
 			if(*ptr != '"') {
-				g_string_append_unichar(value, *ptr);
+				g_string_append_unichar (value, g_utf8_get_char (ptr));
 			}
 			else {
-				ptr++;
-				while (*ptr != '"') {
-					g_string_append_unichar(value, *ptr);
-					ptr++;
+				ptr = g_utf8_next_char (ptr);
+				while (*ptr && *ptr != '"') {
+					g_string_append_unichar (value, g_utf8_get_char (ptr));
+					ptr = g_utf8_next_char (ptr);
 				}
+
+				if (!*ptr)
+					break;
 			}
-			ptr++;
+			ptr = g_utf8_next_char (ptr);
 		}
+
+		contact_field = NOMAP;
+		flags = FLAG_INVALID;
+
 		if(importer == OUTLOOK_IMPORTER) {
-			contact_field = csv_fields_outlook[i].contact_field;
-			flags = csv_fields_outlook[i].flags;
+			if (i >= 0 && i < G_N_ELEMENTS (csv_fields_outlook)) {
+				contact_field = csv_fields_outlook[i].contact_field;
+				flags = csv_fields_outlook[i].flags;
+			}
 		}
 		else if(importer == MOZILLA_IMPORTER) {
-			contact_field = csv_fields_mozilla[i].contact_field;
-			flags = csv_fields_mozilla[i].flags;
+			if (i >= 0 && i < G_N_ELEMENTS (csv_fields_mozilla)) {
+				contact_field = csv_fields_mozilla[i].contact_field;
+				flags = csv_fields_mozilla[i].flags;
+			}
 		}
 		else {
-			contact_field = csv_fields_evolution[i].contact_field;
-			flags = csv_fields_evolution[i].flags;
+			if (i >= 0 && i < G_N_ELEMENTS (csv_fields_evolution)) {
+				contact_field = csv_fields_evolution[i].contact_field;
+				flags = csv_fields_evolution[i].flags;
+			}
 		}
 
 		if(strlen(value->str) != 0) {
 			if (contact_field != NOMAP) {
-				if(importer == OUTLOOK_IMPORTER)
-					e_contact_set(contact, csv_fields_outlook[i].contact_field, value->str);
-				else if(importer == MOZILLA_IMPORTER)
-					e_contact_set(contact, csv_fields_mozilla[i].contact_field, value->str);
-				else
-					e_contact_set(contact, csv_fields_evolution[i].contact_field, value->str);
+				if(importer == OUTLOOK_IMPORTER) {
+					if (i >= 0 && i < G_N_ELEMENTS (csv_fields_outlook))
+						e_contact_set (contact, csv_fields_outlook[i].contact_field, value->str);
+				} else if(importer == MOZILLA_IMPORTER) {
+					if (i >= 0 && i < G_N_ELEMENTS (csv_fields_mozilla))
+						e_contact_set (contact, csv_fields_mozilla[i].contact_field, value->str);
+				} else {
+					if (i >= 0 && i < G_N_ELEMENTS (csv_fields_evolution)) {
+						if (csv_fields_evolution[i].contact_field == E_CONTACT_WANTS_HTML)
+							e_contact_set (contact, csv_fields_evolution[i].contact_field, GINT_TO_POINTER (g_ascii_strcasecmp (value->str, "TRUE") == 0));
+						else
+							e_contact_set (contact, csv_fields_evolution[i].contact_field, value->str);
+					}
+				}
 			}
 			else {
 				switch (flags) {
@@ -482,7 +517,7 @@ parseLine (CSVImporter *gci, EContact *contact, char **buf) {
 		i++;
 		g_string_free(value, TRUE);
 		if(*ptr != '\n')
-			ptr++;
+			ptr = g_utf8_next_char (ptr);
 	}
 	if(strlen(home_street->str) != 0)
 		home_address->street = g_strdup(home_street->str);
@@ -509,6 +544,8 @@ parseLine (CSVImporter *gci, EContact *contact, char **buf) {
 			e_contact_set(contact, E_CONTACT_BIRTH_DATE, bday);
 	}
 
+	g_free (do_free);
+
 	return TRUE;
 }
 
@@ -537,20 +574,20 @@ getNextCSVEntry(CSVImporter *gci, FILE *f) {
 		if (c == EOF)
 			return NULL;
 		if (c == '\n') {
-			g_string_append_unichar(line, c);
+			g_string_append_c (line, c);
 			break ;
 		}
 		if (c == '"') {
-			g_string_append_unichar(line, c);
+			g_string_append_c (line, c);
 			c = fgetc (f);
-			while (c != '"') {
-				g_string_append_unichar(line, c);
+			while (!feof (f) && c != '"') {
+				g_string_append_c (line, c);
 				c = fgetc (f);
 			}
-			g_string_append_unichar(line, c);
+			g_string_append_c (line, c);
 		}
 		else
-			g_string_append_unichar(line, c);
+			g_string_append_c (line, c);
 	}
 
 	if(gci->count == 0 && importer != MOZILLA_IMPORTER) {
@@ -561,20 +598,20 @@ getNextCSVEntry(CSVImporter *gci, FILE *f) {
 			if (c == EOF)
 				return NULL;
 			if (c == '\n') {
-				g_string_append_unichar(line, c);
+				g_string_append_c (line, c);
 				break ;
 			}
 			if (c == '"') {
-				g_string_append_unichar(line, c);
+				g_string_append_c (line, c);
 				c = fgetc (f);
-				while (c != '"') {
-					g_string_append_unichar(line, c);
+				while (!feof (f) && c != '"') {
+					g_string_append_c (line, c);
 					c = fgetc (f);
 				}
-				g_string_append_unichar(line, c);
+				g_string_append_c (line, c);
 			}
 			else
-				g_string_append_unichar(line, c);
+				g_string_append_c (line, c);
 		}
 		gci->count ++;
 	}
@@ -593,7 +630,7 @@ getNextCSVEntry(CSVImporter *gci, FILE *f) {
 
 	buf = str->str;
 
-	if(!parseLine (gci, contact, &buf)) {
+	if(!parseLine (gci, contact, buf)) {
 		g_object_unref(contact);
 		return NULL;
 	}
