@@ -1,25 +1,25 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
-/* e-tasks.c
- *
- * Copyright (C) 2001-2003  Ximian, Inc.
- *
+/*
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
  *
- * Authors: Federico Mena Quintero <federico@ximian.com>
+ *
+ * Authors:
+ *		Federico Mena Quintero <federico@ximian.com>
  *	    Damon Chaplin <damon@ximian.com>
- *          Rodrigo Moya <rodrigo@ximian.com>
+ *      Rodrigo Moya <rodrigo@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -27,18 +27,19 @@
 #endif
 
 #include <string.h>
-#include <gnome.h>
+#include <gio/gio.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <libgnomevfs/gnome-vfs-ops.h>
 #include <libedataserver/e-categories.h>
 #include <libecal/e-cal-time-util.h>
 #include <gtkhtml/gtkhtml.h>
 #include <gtkhtml/gtkhtml-stream.h>
 #include <libedataserver/e-time-utils.h>
+#include <e-util/e-util.h>
 #include <e-util/e-categories-config.h>
 #include "calendar-config.h"
 #include "e-cal-component-preview.h"
+#include <camel/camel-mime-filter-tohtml.h>
 
 struct _ECalComponentPreviewPrivate {
 	GtkWidget *html;
@@ -51,14 +52,8 @@ G_DEFINE_TYPE (ECalComponentPreview, e_cal_component_preview, GTK_TYPE_TABLE)
 static void
 on_link_clicked (GtkHTML *html, const char *url, gpointer data)
 {
-        GError *err = NULL;
-
-        gnome_url_show (url, &err);
-
-	if (err) {
-		g_warning ("gnome_url_show: %s", err->message);
-                g_error_free (err);
-        }
+	/* FIXME Pass a parent window. */
+	e_show_uri (NULL, url);
 }
 
 static void
@@ -78,27 +73,43 @@ on_url_cb (GtkHTML *html, const char *url, gpointer data)
 }
 
 /* Callback used when the user selects a URL in the HTML widget */
-static void
-url_requested_cb (GtkHTML *html, const char *url, GtkHTMLStream *stream, gpointer data)
+void
+e_cal_comp_preview_url_requested_cb (GtkHTML *html, const char *url, GtkHTMLStream *html_stream, gpointer data)
 {
-	if (!strncmp ("file:///", url, strlen ("file:///"))) {
-		GnomeVFSHandle *handle;
-		GnomeVFSResult result;
-		char buffer[4096];
+	int len = strlen ("file:///");
 
-		if (gnome_vfs_open (&handle, url, GNOME_VFS_OPEN_READ) == GNOME_VFS_OK) {
-			do {
-				GnomeVFSFileSize bread;
+	if (!strncmp ("file:///", url, len)) {
+		GFile *file;
+		const char *path = url + len - 1;
 
-				result = gnome_vfs_read (handle, buffer, sizeof (buffer), &bread);
-				if (result == GNOME_VFS_OK)
-					gtk_html_stream_write (stream, buffer, bread);
-			} while (result == GNOME_VFS_OK);
+		g_return_if_fail (html_stream != NULL);
+		g_return_if_fail (path != NULL);
 
-			gnome_vfs_close (handle);
+		file = g_file_new_for_path (path);
+		if (file) {
+			char buffer[4096];
+			GInputStream *stream;
 
-			if (result == GNOME_VFS_ERROR_EOF)
-				gtk_html_stream_close (stream, GTK_HTML_STREAM_OK);
+			/* ignore errors here */
+			stream = G_INPUT_STREAM (g_file_read (file, NULL, NULL));
+
+			if (stream) {
+				gssize bread;
+
+				do {
+					/* ignore errors here as well */
+					bread = g_input_stream_read (stream, buffer, sizeof (buffer), NULL, NULL);
+					if (bread > 0)
+						gtk_html_stream_write (html_stream, buffer, bread);
+				} while (bread > 0);
+
+				g_input_stream_close (stream, NULL, NULL);
+				g_object_unref (stream);
+
+				gtk_html_stream_close (html_stream, GTK_HTML_STREAM_OK);
+			}
+
+			g_object_unref (file);
 		}
 	}
 }
@@ -199,9 +210,9 @@ write_html (GtkHTMLStream *stream, ECal *ecal, ECalComponent *comp, icaltimezone
 		gtk_html_stream_printf (stream, "<TR><TD VALIGN=\"TOP\" ALIGN=\"RIGHT\"><B>%s</B></TD><TD>%s</TD></TR>",
 					_("Start Date:"), str);
 
-		e_cal_component_free_datetime (&dt);
 		g_free (str);
 	}
+	e_cal_component_free_datetime (&dt);
 
 	/* write end date */
 	e_cal_component_get_dtend (comp, &dt);
@@ -210,9 +221,9 @@ write_html (GtkHTMLStream *stream, ECal *ecal, ECalComponent *comp, icaltimezone
 		gtk_html_stream_printf (stream, "<TR><TD VALIGN=\"TOP\" ALIGN=\"RIGHT\"><B>%s</B></TD><TD>%s</TD></TR>",
 					_("Start Date:"), str);
 
-		e_cal_component_free_datetime (&dt);
 		g_free (str);
 	}
+	e_cal_component_free_datetime (&dt);
 
 	/* write Due Date */
 	e_cal_component_get_due (comp, &dt);
@@ -221,9 +232,9 @@ write_html (GtkHTMLStream *stream, ECal *ecal, ECalComponent *comp, icaltimezone
 		gtk_html_stream_printf (stream, "<TR><TD VALIGN=\"TOP\" ALIGN=\"RIGHT\"><B>%s</B></TD><TD>%s</TD></TR>",
 					_("Due Date:"), str);
 
-		e_cal_component_free_datetime (&dt);
 		g_free (str);
 	}
+	e_cal_component_free_datetime (&dt);
 
 	/* write status */
 	gtk_html_stream_printf (stream, "<TR><TD VALIGN=\"TOP\" ALIGN=\"RIGHT\"><B>%s</B></TD>", _("Status:"));
@@ -273,30 +284,21 @@ write_html (GtkHTMLStream *stream, ECal *ecal, ECalComponent *comp, icaltimezone
 
 		gtk_html_stream_printf (stream, "<TR><TD VALIGN=\"TOP\" ALIGN=\"RIGHT\"><B>%s</B></TD>", _("Description:"));
 
-		gtk_html_stream_printf (stream, "<TD><PRE>");
+		gtk_html_stream_printf (stream, "<TD><TT>");
 
 		for (node = l; node != NULL; node = node->next) {
-			gint i, len;
-			GString *string = g_string_new (NULL);;
+			char *html;
 
 			text = * (ECalComponentText *) node->data;
-			len =  text.value ? strlen (text.value) : 0;
-			for (i = 0; i <len ; i++) {
-				if (text.value[i] == '\n')
-					string = g_string_append_len (string, "<BR>", 4);
-				else if (text.value[i] == '<')
-					string = g_string_append_len (string, "&lt;", 4);
-				else if (text.value[i] == '>')
-					string = g_string_append_len (string, "&gt;", 4);
-				else
-					string = g_string_append_c (string, text.value[i]);
-			}
+			html = camel_text_to_html (text.value ? text.value : "", CAMEL_MIME_FILTER_TOHTML_CONVERT_NL | CAMEL_MIME_FILTER_TOHTML_CONVERT_SPACES | CAMEL_MIME_FILTER_TOHTML_CONVERT_URLS | CAMEL_MIME_FILTER_TOHTML_CONVERT_ADDRESSES, 0);
 
-			gtk_html_stream_printf (stream, "%s", string->str);
-			g_string_free (string, TRUE);
+			if (html)
+				gtk_html_stream_printf (stream, "%s", html);
+
+			g_free (html);
 		}
 
-		gtk_html_stream_printf (stream, "</PRE></TD></TR>");
+		gtk_html_stream_printf (stream, "</TT></TD></TR>");
 
 		e_cal_component_free_text_list (l);
 	}
@@ -328,7 +330,7 @@ e_cal_component_preview_init (ECalComponentPreview *preview)
 	gtk_html_load_empty (GTK_HTML (priv->html));
 
 	g_signal_connect (G_OBJECT (priv->html), "url_requested",
-			  G_CALLBACK (url_requested_cb), NULL);
+			  G_CALLBACK (e_cal_comp_preview_url_requested_cb), NULL);
 	g_signal_connect (G_OBJECT (priv->html), "link_clicked",
 			  G_CALLBACK (on_link_clicked), preview);
 	g_signal_connect (G_OBJECT (priv->html), "on_url",
@@ -447,3 +449,11 @@ e_cal_component_preview_clear (ECalComponentPreview *preview)
 	gtk_html_load_empty (GTK_HTML (priv->html));
 }
 
+GtkWidget *
+e_cal_component_preview_get_html (ECalComponentPreview *preview)
+{
+	g_return_val_if_fail (preview != NULL, NULL);
+	g_return_val_if_fail (E_IS_CAL_COMPONENT_PREVIEW (preview), NULL);
+
+	return preview->priv->html;
+}
