@@ -1,24 +1,24 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
-/* tasks-control.c
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
+/*
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Damon Chaplin <damon@ximian.com>
+ *	    Ettore Perazzoli <ettore@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * Authors: Damon Chaplin <damon@ximian.com>
- *	    Ettore Perazzoli
  */
 
 #ifdef HAVE_CONFIG_H
@@ -27,15 +27,11 @@
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <libgnome/gnome-util.h>
-#include <libgnomeui/gnome-dialog.h>
-#include <libgnomeui/gnome-dialog-util.h>
-#include <libgnomeui/gnome-stock-icons.h>
 #include <bonobo/bonobo-control.h>
 #include <bonobo/bonobo-ui-util.h>
 #include <e-util/e-dialog-utils.h>
-#include <e-util/e-print.h>
 #include <e-util/e-icon-factory.h>
+#include <e-util/e-print.h>
 #include <e-util/e-util-private.h>
 #include "dialogs/cal-prefs-dialog.h"
 #include "calendar-config.h"
@@ -47,6 +43,7 @@
 #include "evolution-shell-component-utils.h"
 #include "e-util/e-menu.h"
 #include "e-cal-menu.h"
+#include "e-cal-component-preview.h"
 #include "e-util/e-menu.h"
 #include "itip-utils.h"
 
@@ -100,11 +97,19 @@ static void tasks_control_view_preview	       (BonoboUIComponent *uic,
 						const char *state,
 						void *data);
 
+struct focus_changed_data {
+	BonoboControl *control;
+	ETasks *tasks;
+};
+
+static gboolean tasks_control_focus_changed (GtkWidget *widget, GdkEventFocus *event, struct focus_changed_data *fc_data);
+
 BonoboControl *
 tasks_control_new (void)
 {
 	BonoboControl *control;
-	GtkWidget *tasks;
+	GtkWidget *tasks, *preview;
+	struct focus_changed_data *fc_data;
 
 	tasks = e_tasks_new ();
 	if (!tasks)
@@ -120,6 +125,15 @@ tasks_control_new (void)
 
 	g_signal_connect (control, "activate", G_CALLBACK (tasks_control_activate_cb), tasks);
 
+	fc_data = g_new0 (struct focus_changed_data, 1);
+	fc_data->control = control;
+	fc_data->tasks = E_TASKS (tasks);
+
+	preview = e_cal_component_preview_get_html (E_CAL_COMPONENT_PREVIEW (e_tasks_get_preview (fc_data->tasks)));
+	g_object_set_data_full (G_OBJECT (preview), "tasks-ctrl-fc-data", fc_data, g_free);
+	g_signal_connect (preview, "focus-in-event", G_CALLBACK (tasks_control_focus_changed), fc_data);
+	g_signal_connect (preview, "focus-out-event", G_CALLBACK (tasks_control_focus_changed), fc_data);
+
 	return control;
 }
 
@@ -164,11 +178,13 @@ sensitize_items(BonoboUIComponent *uic, struct _tasks_sensitize_item *items, gui
 	}
 }
 
+#define E_CAL_TASKS_PREVIEW_ACTIVE (1<<31)
+
 static struct _tasks_sensitize_item tasks_sensitize_table[] = {
 	{ "TasksOpenTask", E_CAL_MENU_SELECT_ONE },
-	{ "TasksCut", E_CAL_MENU_SELECT_ANY | E_CAL_MENU_SELECT_EDITABLE },
+	{ "TasksCut", E_CAL_MENU_SELECT_ANY | E_CAL_MENU_SELECT_EDITABLE | E_CAL_TASKS_PREVIEW_ACTIVE },
 	{ "TasksCopy", E_CAL_MENU_SELECT_ANY },
-	{ "TasksPaste", E_CAL_MENU_SELECT_EDITABLE },
+	{ "TasksPaste", E_CAL_MENU_SELECT_EDITABLE | E_CAL_TASKS_PREVIEW_ACTIVE },
 	{ "TasksDelete", E_CAL_MENU_SELECT_ANY | E_CAL_MENU_SELECT_EDITABLE },
 	{ "TasksMarkComplete", E_CAL_MENU_SELECT_ANY | E_CAL_MENU_SELECT_EDITABLE | E_CAL_MENU_SELECT_NOTCOMPLETE},
 	{ "TasksPurge",  E_CAL_MENU_SELECT_EDITABLE },
@@ -192,6 +208,7 @@ tasks_control_sensitize_commands (BonoboControl *control, ETasks *tasks, int n_s
 	GPtrArray *events;
 	GSList *selected = NULL, *l = NULL;
 	ECalendarTable *cal_table;
+	GtkWidget *preview;
 
 	uic = bonobo_control_get_ui_component (control);
 	g_return_if_fail (uic != NULL);
@@ -218,6 +235,12 @@ tasks_control_sensitize_commands (BonoboControl *control, ETasks *tasks, int n_s
 	if (ecal)
 		e_cal_is_read_only (ecal, &read_only, NULL);
 
+	preview = e_cal_component_preview_get_html (E_CAL_COMPONENT_PREVIEW (e_tasks_get_preview (tasks)));
+	if (preview && GTK_WIDGET_VISIBLE (preview) && GTK_WIDGET_HAS_FOCUS (preview))
+		t->target.mask = t->target.mask | E_CAL_TASKS_PREVIEW_ACTIVE;
+	else
+		t->target.mask = t->target.mask & (~E_CAL_TASKS_PREVIEW_ACTIVE);
+
 	sensitize_items (uic, tasks_sensitize_table, t->target.mask);
 	e_menu_update_target ((EMenu *)menu, (EMenuTarget *)t);
 }
@@ -233,6 +256,16 @@ selection_changed_cb (ETasks *tasks, int n_selected, gpointer data)
 	tasks_control_sensitize_commands (control, tasks, n_selected);
 }
 
+static gboolean
+tasks_control_focus_changed (GtkWidget *widget, GdkEventFocus *event, struct focus_changed_data *fc_data)
+{
+	g_return_val_if_fail (fc_data != NULL, FALSE);
+
+	tasks_control_sensitize_commands (fc_data->control, fc_data->tasks, -1);
+
+	return FALSE;
+}
+
 static BonoboUIVerb verbs [] = {
 	BONOBO_UI_VERB ("TasksOpenTask", tasks_control_open_task_cmd),
 	BONOBO_UI_VERB ("TasksNewTask", tasks_control_new_task_cmd),
@@ -320,12 +353,6 @@ tasks_control_activate (BonoboControl *control, ETasks *tasks)
 
 	bonobo_ui_component_add_listener(uic, "ViewPreview", tasks_control_view_preview, tasks);
 	bonobo_ui_component_set_prop(uic, "/commands/ViewPreview", "state", state?"1":"0", NULL);
-	/* Show the dialog for setting the timezone if the user hasn't chosen
-	   a default timezone already. This is done in the startup wizard now,
-	   so we don't do it here. */
-#if 0
-	calendar_config_check_timezone_set ();
-#endif
 }
 
 
@@ -389,10 +416,19 @@ tasks_control_copy_cmd                  (BonoboUIComponent      *uic,
 {
 	ETasks *tasks;
 	ECalendarTable *cal_table;
+	GtkWidget *preview;
 
 	tasks = E_TASKS (data);
-	cal_table = e_tasks_get_calendar_table (tasks);
-	e_calendar_table_copy_clipboard (cal_table);
+
+
+	preview = e_cal_component_preview_get_html (E_CAL_COMPONENT_PREVIEW (e_tasks_get_preview (tasks)));
+	if (preview && GTK_WIDGET_VISIBLE (preview) && GTK_WIDGET_HAS_FOCUS (preview)) {
+		/* copy selected text in a preview when that's shown and focused */
+		gtk_html_copy (GTK_HTML (preview));
+	} else {
+		cal_table = e_tasks_get_calendar_table (tasks);
+		e_calendar_table_copy_clipboard (cal_table);
+	}
 }
 
 static void
@@ -541,7 +577,7 @@ tasks_control_forward_cmd (BonoboUIComponent *uic,
                        ECalComponent *comp;
                        comp = e_cal_component_new ();
                        e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (comp_data->icalcomp));
-                       itip_send_comp (E_CAL_COMPONENT_METHOD_PUBLISH, comp, comp_data->client, NULL, NULL, NULL);
+                       itip_send_comp (E_CAL_COMPONENT_METHOD_PUBLISH, comp, comp_data->client, NULL, NULL, NULL, TRUE);
                        g_object_unref (comp);
 	       }
 }
