@@ -2000,7 +2000,7 @@ emft_popup_new_folder (EPopup *ep, EPopupItem *pitem, void *data)
 	CamelFolderInfo *fi;
 
 	if ((fi = em_folder_tree_get_selected_folder_info (emft)) != NULL) {
-		em_folder_utils_create_folder(fi, emft);
+		em_folder_utils_create_folder (fi, emft, NULL);
 		camel_folder_info_free(fi);
 	}
 }
@@ -2550,7 +2550,8 @@ em_folder_tree_get_selected_folder (EMFolderTree *emft)
 		gtk_tree_model_get (model, &iter, COL_POINTER_CAMEL_STORE, &store,
 				    COL_STRING_FULL_NAME, &full_name, -1);
 
-	folder = camel_store_get_folder (store, full_name, CAMEL_STORE_FOLDER_INFO_FAST, &ex);
+	if (store && full_name)
+		folder = camel_store_get_folder (store, full_name, CAMEL_STORE_FOLDER_INFO_FAST, &ex);
 
 	camel_exception_clear (&ex);
 
