@@ -63,14 +63,17 @@ struct _EMNetworkPrefs {
 	struct _GtkToggleButton *sys_proxy;
 	struct _GtkToggleButton *no_proxy;
 	struct _GtkToggleButton *manual_proxy;
+#if 0
 	struct _GtkToggleButton *auto_proxy;
+#endif
 	struct _GtkToggleButton *use_auth;
 
 	struct _GtkEntry *http_host;
 	struct _GtkEntry *https_host;
-	struct _GtkEntry *socks_host;
 	struct _GtkEntry *ignore_hosts;
+#if 0
 	struct _GtkEntry *auto_proxy_url;
+#endif
 	struct _GtkEntry *auth_user;
 	struct _GtkEntry *auth_pwd;
 
@@ -78,15 +81,18 @@ struct _EMNetworkPrefs {
 	struct _GtkLabel *lbl_http_port;
 	struct _GtkLabel *lbl_https_host;
 	struct _GtkLabel *lbl_https_port;
-	struct _GtkLabel *lbl_socks_host;
-	struct _GtkLabel *lbl_socks_port;	
 	struct _GtkLabel *lbl_ignore_hosts;
 	struct _GtkLabel *lbl_auth_user;
 	struct _GtkLabel *lbl_auth_pwd;
 
 	struct _GtkSpinButton *http_port;
 	struct _GtkSpinButton *https_port;
-	struct _GtkSpinButton *socks_port;	
+#if 0
+	struct _GtkLabel *lbl_socks_host;
+	struct _GtkEntry *socks_host;
+	struct _GtkLabel *lbl_socks_port;
+	struct _GtkSpinButton *socks_port;
+#endif
 };
 
 struct _EMNetworkPrefsClass {
